pub fn extract(main_world: &mut World, render_world: &mut World)Expand description
Executes the ExtractSchedule step of the renderer.
This updates the render world with the extracted ECS data of the current frame.
pub fn extract(main_world: &mut World, render_world: &mut World)Executes the ExtractSchedule step of the renderer.
This updates the render world with the extracted ECS data of the current frame.